#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Wed Mar 27 14:48:38 2019

@author: ZhexingLi
"""

# Setup file for Radvel fitting

# Required packages for setup
import pandas as pd
import numpy as np
import radvel

# Define global planetary system and dataset parameters
starname = 'HD10000'
nplanets = 1    # number of planets in the system
instnames = ['AAT']    # list of instrument names. Can be whatever you like but should match 'tel' column in the input file.
ntels = len(instnames)       # number of instruments with unique velocity zero-points
fitting_basis = 'per tc secosw sesinw k'    # Fitting basis, see radvel.basis.BASIS_NAMES for available basis names
bjd0 = 2450000.
planet_letters = {1: 'b'}

# Define prior centers (initial guesses) in a basis of your choice (need not be in the fitting basis)
anybasis_params = radvel.Parameters(nplanets,basis='per tp e w k')    # initialize Parameters object

anybasis_params['per1'] = radvel.Parameter(value=3436)    # period of 1st planet
anybasis_params['tp1'] = radvel.Parameter(value=2457000)    # time of periastron of 1st planet
anybasis_params['e1'] = radvel.Parameter(value=0.36)          # eccentricity of 'per tp secosw sesinw k'1st planet
anybasis_params['w1'] = radvel.Parameter(value=3.706)      # argument of periastron of the star's orbit for 1st planet
anybasis_params['k1'] = radvel.Parameter(value=5.695)         # velocity semi-amplitude for 1st planet

anybasis_params['dvdt'] = radvel.Parameter(value=0.0)        # slope
anybasis_params['curv'] = radvel.Parameter(value=0.0)         # curvature

anybasis_params['gamma_AAT'] = radvel.Parameter(1.0)      # velocity zero-point for instrument
anybasis_params['jit_AAT'] = radvel.Parameter(value=4.0)        # jitter for instrument     


# Convert input orbital parameters into the fitting basis
params = anybasis_params.basis.to_any_basis(anybasis_params,fitting_basis)

# Set the 'vary' attributes of each of the parameters in the fitting basis. A parameter's 'vary' attribute should
# be set to False if you wish to hold it fixed during the fitting process. By default, all 'vary' parameters
# are set to True.
#params['secosw1'].vary = False
#params['sesinw1'].vary = False
#params['tc1'].vary = False
#params['per1'].vary = False
#params['k1'].vary = False
#params['gamma_COR98'].vary = False
#params['jit_COR98'].vary = False
#params['gamma_COR07'].vary = False
#params['jit_COR07'].vary = False
#params['gamma_HARPS'].vary = False
#params['jit_HARPS'].vary = False
params['dvdt'].vary = False
params['curv'].vary = False

# Load radial velocity data, in this example the data is contained in an hdf file,
# the resulting dataframe or must have 'time', 'mnvel', 'errvel', and 'tel' keys
# the velocities are expected to be in m/s
path = ''
data = pd.read_csv(path,header=None,skiprows=1,delim_whitespace=True,names=('time','mnvel','errvel','tel'))
#data['tel'] = 'AAT'


# Define prior shapes and widths here.
priors = [
    radvel.prior.EccentricityPrior(nplanets),           # Keeps eccentricity < 1
    radvel.prior.PositiveKPrior(nplanets),             # Keeps K > 0
    radvel.prior.Gaussian('k1', params['k1'].value, 5), # Gaussian prior on tp1 with center at tc1 and width 0.01 days
    radvel.prior.Gaussian('per1', params['per1'].value, 3000),
    radvel.prior.Gaussian('tc1', params['tc1'].value, 10000),
    radvel.prior.HardBounds('jit_AAT', 0.0, 10.0)
]

# abscissa for slope and curvature terms (should be near mid-point of time baseline)
time_base = np.mean([np.min(data.time), np.max(data.time)])  


# optional argument that can contain stellar mass in solar units (mstar) and
# uncertainty (mstar_err). If not set, mstar will be set to nan.
stellar = dict(mstar=1.125, mstar_err=0.093)

